California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Choose an Election Cycle: 2021 through 2022 Historical
HERE ARE YOUR RESULTS: Election Dates (Dates appear according to the Election Cycle above) 2021 - 2022 Election Dates: 1. SPECIAL ELECTION Tuesday, 3/2/21 2. SPECIAL ELECTION Tuesday, 4/6/21 3. SPECIAL ELECTION RUNOFF Tuesday, 5/4/21 4. SPECIAL ELECTION Tuesday, 5/18/21 5. SPECIAL ELECTION RUNOFF Tuesday, 6/8/21 6. SPECIAL ELECTION Tuesday, 6/29/21 7. SPECIAL ELECTION RUNOFF Tuesday, 7/20/21 8. SPECIAL ELECTION RUNOFF Tuesday, 8/31/21 9. SPECIAL ELECTION Thursday, 9/30/21 10. SPECIAL ELECTION Monday, 11/15/21 11. SPECIAL ELECTION RUNOFF Thursday, 12/9/21 12. SPECIAL ELECTION Saturday, 1/1/22 13. PRIMARY ELECTION Tuesday, 6/7/22 14. GENERAL ELECTION Tuesday, 11/8/22
If you are searching for campaign finance information related to a specific office this is the place to begin. Included are officeholders for Governor, Lieutenant Governor, Secretary of State, Attorney General, State Controller, State Treasurer, Insurance Commissioner, State Superintendent of Public Instruction, Board of Equalization, State Senate, and State Assembly. Here you will find their names, campaign committees, and other information.
SENATE DISTRICTS
STATE SENATE 01
DAHLE, BRIAN
| STATE SENATE 03
DODD, BILL
STATE SENATE 05
EGGMAN, SUSAN
| STATE SENATE 07
GLAZER, STEVEN
STATE SENATE 09
SKINNER, NANCY
| STATE SENATE 11
WIENER, SCOTT D.
STATE SENATE 13
BECKER, JOSH
| STATE SENATE 15
CORTESE, DAVID DOMINIC
STATE SENATE 17
LAIRD, JOHN S.
| STATE SENATE 19
LIMON, S. MONIQUE
STATE SENATE 21
WILK, SCOTT T.
| STATE SENATE 23
BOGH, ROSILICIE OCHOA
STATE SENATE 25
PORTANTINO, ANTHONY
| STATE SENATE 27
STERN, HENRY
STATE SENATE 29
NEWMAN, JOSH B.
| STATE SENATE 30
KAMLAGER, SYDNEY
STATE SENATE 31
ROTH, RICHARD D.
| STATE SENATE 33
GONZALEZ, LENA
STATE SENATE 35
BRADFORD, STEVEN
| STATE SENATE 37
MIN, DAVE
STATE SENATE 39
ATKINS, TONI G.
ASSEMBLY DISTRICTS
ASSEMBLY 01
DAHLE, MEGAN
| ASSEMBLY 02
WOOD, JIM
ASSEMBLY 03
GALLAGHER, JAMES
| ASSEMBLY 04
AGUIAR-CURRY, CECILIA
ASSEMBLY 05
BIGELOW, FRANK
| ASSEMBLY 06
KILEY, KEVIN
ASSEMBLY 07
MC CARTY, KEVIN
| ASSEMBLY 08
COOLEY, KEN
ASSEMBLY 09
COOPER, JIM
| ASSEMBLY 10
LEVINE, MARC
ASSEMBLY 11
FRAZIER, JR., JAMES L
| ASSEMBLY 12
FLORA, HEATH
ASSEMBLY 13
VILLAPUDUA, CARLOS
| ASSEMBLY 14
GRAYSON, TIM
ASSEMBLY 15
WICKS, BUFFY
| ASSEMBLY 16
BAUER-KAHAN, REBECCA
ASSEMBLY 17
CHIU, DAVID
| ASSEMBLY 18
BONTA, ROB
ASSEMBLY 19
TING, PHIL
| ASSEMBLY 20
QUIRK, BILL
ASSEMBLY 21
GRAY, ADAM C.
| ASSEMBLY 22
MULLIN, KEVIN C.
ASSEMBLY 23
PATTERSON, JIM
| ASSEMBLY 24
BERMAN, MARC
ASSEMBLY 25
LEE, ALEX T.
| ASSEMBLY 26
MATHIS, DEVON J.
ASSEMBLY 27
KALRA, ASH
| ASSEMBLY 28
LOW, EVAN
ASSEMBLY 29
STONE, MARK
| ASSEMBLY 30
RIVAS, ROBERT
ASSEMBLY 31
ARAMBULA, JOAQUIN
| ASSEMBLY 32
SALAS JR., RUDY
ASSEMBLY 33
SMITH, THURSTON
| ASSEMBLY 34
FONG, VINCENT
ASSEMBLY 35
CUNNINGHAM, JORDAN
| ASSEMBLY 36
LACKEY, THOMAS W.
ASSEMBLY 37
BENNETT, STEPHEN A.
| ASSEMBLY 38
VALLADARES, SUZETTE M.
ASSEMBLY 39
RIVAS, LUZ
| ASSEMBLY 40
RAMOS, JAMES
ASSEMBLY 41
HOLDEN, CHRIS
| ASSEMBLY 42
MAYES, CHAD
ASSEMBLY 43
FRIEDMAN, LAURA
| ASSEMBLY 44
IRWIN, JACQUI V.
ASSEMBLY 45
GABRIEL, JESSE
| ASSEMBLY 46
NAZARIAN, ADRIN
ASSEMBLY 47
REYES, ELOISE GOMEZ
| ASSEMBLY 48
RUBIO, BLANCA
ASSEMBLY 49
CHAU, ED
| ASSEMBLY 50
BLOOM, RICHARD
ASSEMBLY 51
CARRILLO, WENDY
| ASSEMBLY 52
RODRIGUEZ, FREDDIE
ASSEMBLY 53
SANTIAGO, MIGUEL
| ASSEMBLY 54
KAMLAGER, SYDNEY
ASSEMBLY 55
CHEN, PHILLIP
| ASSEMBLY 56
GARCIA, EDUARDO
ASSEMBLY 57
CALDERON, LISA
| ASSEMBLY 58
GARCIA, CRISTINA
ASSEMBLY 59
JONES-SAWYER SR., REGINALD BYRON
| ASSEMBLY 60
CERVANTES, SABRINA
ASSEMBLY 61
MEDINA, JOSE J.
| ASSEMBLY 62
BURKE, AUTUMN
ASSEMBLY 63
RENDON, ANTHONY
| ASSEMBLY 64
GIPSON, MIKE
ASSEMBLY 65
QUIRK-SILVA, SHARON
| ASSEMBLY 66
MURATSUCHI, AL
ASSEMBLY 67
SEYARTO, KELLY
| ASSEMBLY 68
CHOI, STEVEN
ASSEMBLY 69
DALY, TOM
| ASSEMBLY 70
O'DONNELL, PATRICK
ASSEMBLY 71
VOEPEL, RANDY G.
| ASSEMBLY 72
NGUYEN, JANET
ASSEMBLY 73
DAVIES, LAURIE A.
| ASSEMBLY 74
PETRIE-NORRIS, COTTIE
ASSEMBLY 75
WALDRON, MARIE
| ASSEMBLY 76
BOERNER HORVATH, TASHA
ASSEMBLY 77
MAIENSCHEIN, BRIAN
| ASSEMBLY 78
WARD, CHRISTOPHER M.
ASSEMBLY 79
WEBER, AKILAH
| ASSEMBLY 80
GONZALEZ, LORENA S.